View source: R/snowfitfunctions.R
| pSnow | R Documentation |
The function pSnow estimates snow depth, albedo, density and temperature
pSnow(
weather,
precd,
snowenv = "Taiga",
STparams,
meltfact = 0.11,
snowem = 0.99,
zm = 0.002,
umin = 0.5,
astc = 1.5,
initdepth = 0
)
weather |
a data.frame of weather variables (see details). |
precd |
a vector of daily precipitation (mm). |
snowenv |
one of |
STparams |
an object of class |
meltfact |
a snow melt coefficient, as returned by |
snowem |
optionally, snow emissivity |
zm |
optionally, roughness length for momentum transfer of snow surface (m) |
umin |
optionally, numeric value indicating minimum wind speed used in conductivity calculations (m/s) |
astc |
optionally, numeric value indicating the temperature at which precipitation falls as snow (deg C) |
initdepth |
single numeric value giving the initial snow depth (cm) |
The format and and units of weather must follow that in the example
dataset climdata. The paramater snowenv is used to compute snow density
following Sturm et al (2010) J Hydrometeorology 11: 1380-1393.
a list of the following:
snowdepth snow depth (cm)
snowdens snow density (g/cm^3)
snowtemp snow temperature (deg C)
snowref snow reflectance (range 0 to 1)
snowfall snow fall (cm) at each time increment
snowmelt snow melt (cm) at each time increment
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.